@@ -81,6 +81,7 @@ from magpy.lib.format_gfztmp import *
 from magpy.lib.format_neic import *
 from magpy.lib.format_rcs import *
 from magpy.lib.format_pha import *
+from magpy.lib.format_basiccsv import *
 
 from magpy.lib.format_imf import *
 try:
@@ -138,18 +139,12 @@ def isFormat(filename, format_type):
     elif (format_type == "DTU1"): # ASCII Data from the DTU's FGE systems
         if (isDTU1(filename)):
             return True
-    elif (format_type == "ACECDF"):
-        if (isACECDF(filename)):
-            return True
     elif (format_type == "PYSTR"):
         if (isPYSTR(filename)):
             return True
     elif (format_type == "PYASCII"):
         if (isPYASCII(filename)):
             return True
-    elif (format_type == "PYCDF"):
-        if (isPYCDF(filename)):
-            return True
     elif (format_type == "PYBIN"):
         if (isPYBIN(filename)):
             return True
@@ -222,6 +217,12 @@ def isFormat(filename, format_type):
     elif (format_type == "DKA"): # Intermagnet K-value Format
         if (isDKA(filename)):
             return True
+    elif (format_type == "ACECDF"):
+        if (isACECDF(filename)):
+            return True
+    elif (format_type == "PYCDF"):
+        if (isPYCDF(filename)):
+            return True
     elif (format_type == "IMAGCDF"): # Intermagnet CDF Format
         if (isIMAGCDF(filename)):
             return True
@@ -279,6 +280,9 @@ def isFormat(filename, format_type):
     elif (format_type == "GFZTMP"): # Data from the USB temperature logger
         if (isGFZTMP(filename)):
             return True
+    elif (format_type == "CSV"): # Basic CSV data
+        if (isCSV(filename)):
+            return True
     elif (format_type in ["PYNC", "AUTODIF", "SERMUL", "SERSIN", "LATEX"]): # Not yet supported
         return False
     elif (format_type == "UNKOWN"): # Unkown
@@ -298,8 +302,6 @@ def readFormat(filename, format_type, headonly=False, **kwargs):
         return readIMF(filename, headonly, **kwargs)
     elif (format_type == "IAF"):
         return readIAF(filename, headonly, **kwargs)
-    elif (format_type == "IMAGCDF"):
-        return readIMAGCDF(filename, headonly, **kwargs)
     elif (format_type == "BLV"): # Intermagnet IBFV2.00
         return readBLV(filename, headonly, **kwargs)
     elif (format_type == "IYFV"): # Intermagnet IYVF1.01
@@ -308,8 +310,6 @@ def readFormat(filename, format_type, headonly=False, **kwargs):
         return readDKA(filename, headonly, **kwargs)
     elif (format_type == "DIDD"):
         return readDIDD(filename, headonly, **kwargs)
-    elif (format_type == "ACECDF"): # cdf ACE
-        return readACECDF(filename, headonly, **kwargs)
     elif (format_type == "GDASA1"):
         return readGDASA1(filename, headonly, **kwargs)
     elif (format_type == "GDASB1"):
@@ -326,6 +326,10 @@ def readFormat(filename, format_type, headonly=False, **kwargs):
         return readPYSTR(filename, headonly, **kwargs)
     elif (format_type == "PYASCII"):
         return readPYASCII(filename, headonly, **kwargs)
+    elif (format_type == "IMAGCDF"):
+        return readIMAGCDF(filename, headonly, **kwargs)
+    elif (format_type == "ACECDF"): # cdf ACE
+        return readACECDF(filename, headonly, **kwargs)
     elif (format_type == "PYCDF"):
         return readPYCDF(filename, headonly, **kwargs)
     elif (format_type == "PYBIN"):
@@ -397,6 +401,8 @@ def readFormat(filename, format_type, headonly=False, **kwargs):
         return readNEIC(filename, headonly, **kwargs)
     elif (format_type == "PHA"):
         return readPHA(filename, headonly, **kwargs)
+    elif (format_type == "CSV"):
+        return readCSV(filename, headonly, **kwargs)
     else:
         logger.info("No valid format found ({}). Returning empty stream.".format(format_type))
         return DataStream(empty,empty.header)
@@ -441,6 +447,8 @@ def writeFormat(datastream, filename, format_type, **kwargs):
         return writeAUTODIF_FREAD(datastream, filename, **kwargs)
     elif (format_type == "CR800"):
         return writeCR800(datastream, filename, **kwargs)
+    elif (format_type == "CSV"):
+        return writeCSV(datastream, filename, **kwargs)
     elif (format_type == "LATEX"):
         return writeLATEX(datastream, filename, **kwargs)
     else:
